<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Prints a particular instance of pdfpager
 *
 * You can have a rather longer description of the file as well,
 * if you like, and it can span multiple lines.
 *
 * @package    mod
 * @subpackage pdfpager
 * @copyright  2011 Geoff Eggins
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

/// (Replace pdfpager with the name of your module and remove this line)

require_once(dirname(dirname(dirname(__FILE__))).'/config.php');
require_once($CFG->dirroot.'/mod/pdfpager/locallib.php');
require_once(dirname(__FILE__).'/lib.php');
require_once($CFG->dirroot.'/mod/pdfpager/Zend/Pdf.php');

$id = optional_param('id', 0, PARAM_INT); // course_module ID, or
$n  = optional_param('n', 0, PARAM_INT);  // pdfpager instance ID - it should be named as the first character of the module
$r        = optional_param('r', 0, PARAM_INT);  // Resource instance ID
$redirect = optional_param('redirect', 0, PARAM_BOOL);


	if ($id) {
		$cm         = get_coursemodule_from_id('pdfpager', $id, 0, false, MUST_EXIST);
		$course     = $DB->get_record('course', array('id' => $cm->course), '*', MUST_EXIST);
		$pdfpager  = $DB->get_record('pdfpager', array('id' => $cm->instance), '*', MUST_EXIST);
	} elseif ($n) {
		$pdfpager  = $DB->get_record('pdfpager', array('id' => $n), '*', MUST_EXIST);
		$course     = $DB->get_record('course', array('id' => $pdfpager->course), '*', MUST_EXIST);
		$cm         = get_coursemodule_from_instance('pdfpager', $pdfpager->id, $course->id, false, MUST_EXIST);
	} else {
		error('You must specify a course_module ID or an instance ID');
	}



require_login($course, true, $cm);
$context = get_context_instance(CONTEXT_MODULE, $cm->id);
require_capability('mod/resource:view', $context);

add_to_log($course->id, 'pdfpager', 'view', "view.php?id={$cm->id}", $pdfpager->name, $cm->id);

// Update 'viewed' state if required by completion system
$completion = new completion_info($course);
$completion->set_module_viewed($cm);

$PAGE->set_url('/mod/pdfpager/view.php', array('id' => $cm->id));


$fs = get_file_storage();
$files = $fs->get_area_files($context->id, 'mod_pdfpager', 'content', 0, 'sortorder DESC, id ASC', false); // TODO: this is not very efficient!!

if (count($files) < 1) {
    resource_print_filenotfound($pdfpager, $cm, $course);
    die;
	//echo "I got in here";
	//die;
} else {
    $file = reset($files);
    unset($files);
	//echo "I got in the bottom here";
	//die;
}


$filecontents = trim($file->get_content());

$displaytype = RESOURCELIB_DISPLAY_DOWNLOAD;

$pdfpager->mainfile = $file->get_filename();
//$displaytype = RESOURCELIB_DISPLAY_OPEN;
    if (!isset($_SERVER['HTTP_REFERER']) || strpos($_SERVER['HTTP_REFERER'], 'modedit.php') === false) {
        $redirect = true;
    }


if ($redirect) {

 
    $path = '/'.$context->id.'/mod_pdfpager/content/'.$pdfpager->revision.$file->get_filepath().$file->get_filename();
	$fullurl = moodle_url::make_file_url('/pluginfile.php', $path, $displaytype == RESOURCELIB_DISPLAY_DOWNLOAD);
    //echo $fullurl;
	
	try {
		// pdfpager stuff
		$extractor = new Zend_Pdf_Resource_Extractor();
		 
		// Load PDF document from file contents. 
		$pdfbor = Zend_Pdf::parse($filecontents); 

		$startingPage = (($pdfpager->startpage)-1);
		$finishingPage = (($pdfpager->endpage)-1);
		
		$counter = $startingPage;
		$pdfex = new Zend_Pdf();
		while ($counter <= $finishingPage){
			$pageToTransfer = $extractor->clonePage($pdfbor->pages[$counter]);
			$pdfex->pages[] = $pageToTransfer;
			$counter++;
		}
		
		// Get PDF document as a string 
		$pdfData = $pdfex->render(); 

		header("Content-Disposition: inline; filename=pages".($startingPage+1)."TO".($finishingPage+1)."OF".$file->get_filename()); 
		header("Content-type: application/x-pdf"); 
		echo $pdfData; 

		} catch (Zend_Pdf_Exception $e) { 
		//If a Zend exception happens, just serve the full file. 
		redirect($fullurl);
		//if the full file is being served, uncomment the link to get some feedback as to why.
		//die ('PDF error: ' . $e->getMessage());
		
	} catch (Exception $e) {
		//If a Zend exception happens, just serve the full file. 
		redirect($fullurl);
		//if the full file is being served, uncomment the link to get some feedback as to why.
		//die ('Application error: ' . $e->getMessage());    
	}
	
}